Profiles
========

Profile
-------
.. autoclass:: poisson_approval.Profile
    :members:

ProfileOrdinal
--------------
.. autoclass:: poisson_approval.ProfileOrdinal
    :members:
    :inherited-members:

ProfileCardinal
---------------
.. autoclass:: poisson_approval.ProfileCardinal
    :members:
    :inherited-members:

ProfileTwelve
-------------
.. autoclass:: poisson_approval.ProfileTwelve
    :members:
    :inherited-members:

ProfileHistogram
----------------
.. autoclass:: poisson_approval.ProfileHistogram
    :members:
    :inherited-members:
